@@ -2,11 +2,13 @@ import time
 
 import ee
 
-from sepal_ui.scripts import messages as ms
+from sepal_ui.message import ms
+from sepal_ui.scripts import utils as su
+    
+# initialize earth engine
+su.init_ee()
 
-if not ee.data._credentials: ee.Initialize()
-
-def wait_for_completion(task_descripsion, widget_alert):
+def wait_for_completion(task_descripsion, widget_alert=None):
     """Wait until the selected process is finished. Display some output information
 
     Args:
@@ -15,13 +17,27 @@ def wait_for_completion(task_descripsion, widget_alert):
     """
     state = 'UNSUBMITTED'
     while state != 'COMPLETED':
-        widget_alert.add_live_msg(ms.STATUS.format(state))
+        
+        # print in a widget
+        if widget_alert: 
+            widget_alert.add_live_msg(ms.status.format(state))
+            
+        # wait 5 seconds
         time.sleep(5)
                     
-        #search for the task in task_list
+        # search for the task in task_list
         current_task = isTask(task_descripsion)
         state = current_task.state
         
+        if state == 'FAILED':
+            raise Exception(ms.status.format(state))
+        
+    # print in a widget
+    if widget_alert: 
+        widget_alert.add_live_msg(ms.status.format(state), 'success')
+        
+    return state
+        
 def isTask(task_descripsion):
     """Search for the described task in the user Task list return None if nothing is find
     
